"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }// src/common/msg/rpc.ts
var rpcCounter = 1;
var defaultSerialize = (i) => i;
var defaultDeserialize = defaultSerialize;
function setupRPCBasic(options, functions, eventNames = []) {
  const {
    post,
    on,
    serialize = defaultSerialize,
    deserialize = defaultDeserialize,
    log
  } = options;
  const rpcPromiseMap = /* @__PURE__ */ new Map();
  on(async (data) => {
    try {
      const msg = deserialize(data);
      const [mode, args, id, method] = msg;
      if (mode === 1 /* request */ || mode === 2 /* event */) {
        let result, error;
        if (method != null) {
          try {
            const fn = functions[method];
            result = await fn(...args);
          } catch (e) {
            error = String(e);
          }
        } else {
          error = "Method implementation missing";
        }
        if (error)
          _optionalChain([log, 'optionalAccess', _2 => _2.warn, 'call', _3 => _3("error", msg, error)]);
        if (mode === 1 /* request */ && id) {
          if (error)
            post(serialize([4 /* reject */, error, id]));
          else
            post(serialize([3 /* resolve */, result, id]));
        }
      } else if (id) {
        const promise = rpcPromiseMap.get(id);
        if (promise != null) {
          if (mode === 4 /* reject */)
            promise.reject(args);
          else
            promise.resolve(args);
        }
        rpcPromiseMap.delete(id);
      }
    } catch (err) {
      _optionalChain([log, 'optionalAccess', _4 => _4.warn, 'call', _5 => _5("Error on handling RPC data. Invalid?", err, data)]);
    }
  });
  const proxyHandler = {
    get(_, method) {
      const sendEvent = (...args) => {
        post(serialize([2 /* event */, args, null, method]));
      };
      if (options.onlyEvents || eventNames.includes(method)) {
        sendEvent.asEvent = sendEvent;
        return sendEvent;
      }
      const sendCall = (...args) => {
        return new Promise((resolve, reject) => {
          const id = rpcCounter++;
          rpcPromiseMap.set(id, { resolve, reject });
          post(serialize([1 /* request */, args, id, method]));
        });
      };
      sendCall.asEvent = sendEvent;
      return sendCall;
    }
  };
  return { post, serialize, rpcPromiseMap, proxyHandler };
}
function useRPC(functions, options) {
  const { eventNames = [] } = options;
  const { proxyHandler } = setupRPCBasic(options, functions, eventNames);
  return new Proxy({}, proxyHandler);
}
function useRPCHub(options) {
  const eventNames = [];
  const functions = {};
  const { proxyHandler } = setupRPCBasic(options, functions);
  function createRPCProxy() {
    return new Proxy({}, proxyHandler);
  }
  return function(additionalFunctions, additionalEventNames = []) {
    Object.assign(functions, _nullishCoalesce(additionalFunctions, () => ( {})));
    eventNames.push(...additionalEventNames);
    return createRPCProxy();
  };
}




exports.useRPC = useRPC; exports.useRPCHub = useRPCHub;
//# sourceMappingURL=chunk-6LKD7EB2.cjs.map