// src/node/fs.ts
import { mkdir, readFile, rm, stat, writeFile } from "node:fs/promises";
import { join as joinPath, normalize } from "node:path";
import process from "node:process";
function toHumanReadableFilePath(path) {
  const p = normalize(path);
  const h = process.env.HOME;
  if (h && p.startsWith(h))
    return `~${p.slice(h.length)}`;
  return p;
}
async function exists(path) {
  try {
    await stat(path);
  } catch (err) {
    return false;
  }
  return true;
}
function isHiddenPath(path) {
  return path.startsWith(".") || path.includes("/.");
}
async function ensureFolder(...parts) {
  const path = joinPath(...parts);
  if (!await exists(path))
    await mkdir(path, { recursive: true });
  return path;
}
async function removeFolder(...parts) {
  const path = joinPath(...parts);
  if (await exists(path))
    await rm(path, { recursive: true });
  return path;
}
async function readText(...parts) {
  const path = joinPath(...parts);
  if (await exists(path))
    return await readFile(path, "utf-8");
}
async function writeText(path, content) {
  await writeFile(path, content, "utf-8");
}

export {
  toHumanReadableFilePath,
  exists,
  isHiddenPath,
  ensureFolder,
  removeFolder,
  readText,
  writeText
};
//# sourceMappingURL=chunk-7RROEVU7.js.map