import "../../chunk-HMRSQHLY.js";
import "../../chunk-UMUHNSGZ.js";
import "../../chunk-XXA2VCHX.js";
import {
  bitfield,
  createBinaryStreamDecoder,
  createBinaryStreamEncoder
} from "../../chunk-KZGDS2U4.js";
import "../../chunk-757WXGDS.js";
import "../../chunk-MKG75UEC.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-5YRPAB4U.js";
import "../../chunk-QVFQNQV4.js";
import "../../chunk-FLFB2K34.js";
import "../../chunk-264HKVNG.js";
import "../../chunk-HST4VI64.js";
import "../../chunk-MN6DD7TD.js";
import "../../chunk-GZUTQZ3U.js";
import "../../chunk-IRAXCYXQ.js";
import "../../chunk-T2MBDYSL.js";
import "../../chunk-EW6FHLFK.js";
import "../../chunk-OYNSVQOM.js";
import "../../chunk-Q75B3LT2.js";
import "../../chunk-NKARXZR4.js";
import "../../chunk-LUQZ27ZQ.js";
import "../../chunk-HYJBWXV7.js";
import "../../chunk-7OAUULYN.js";
import "../../chunk-AR6BCIEQ.js";
import "../../chunk-SMAIMMCT.js";
import "../../chunk-2OOKKBJ6.js";
import "../../chunk-BZI4YHUE.js";
import "../../chunk-X7W6H72B.js";
import "../../chunk-ZVMU3WSX.js";
import "../../chunk-4EOY6YSF.js";
import "../../chunk-EK32D4RU.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-EC265RJR.js";
import "../../chunk-Q4U2LWXG.js";
import "../../chunk-W7LFRQ22.js";
import "../../chunk-F43DOT7T.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-5RFQXBFU.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-XZKJFOLV.js";
import "../../chunk-MAHFB3CS.js";
import "../../chunk-EJVKADTL.js";
import "../../chunk-ERNLUGKM.js";
import "../../chunk-IXQQW2HU.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-VQP2U5NJ.js";
import "../../chunk-2NUBGBAZ.js";
import "../../chunk-JOGTJBRE.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-FPGKBYJC.js";
import "../../chunk-SIEZSWEQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-SW2CNWDU.js";
import "../../chunk-HWIBO3OW.js";
import "../../chunk-Z4LF2VTM.js";
import "../../chunk-CBA7RGFL.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-2OESVESN.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-V2ICHMP3.js";
import "../../chunk-CFAKTF25.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-VK2OFAYR.js";
import "../../chunk-7NSVDPHN.js";
import {
  Uint8ArrayToHexDump,
  toHex
} from "../../chunk-EWHIXGDN.js";
import "../../chunk-UHUPIXEQ.js";

// src/common/bin/index.spec.ts
describe("encoder", () => {
  it("should write a stream", () => {
    const stream = createBinaryStreamEncoder();
    stream.writeUint32(1);
    stream.write({ a: "99" });
    stream.writeBytes([1, 2, 3], 3);
    stream.write(123);
    const bin = stream.getUint8Array();
    expect(Uint8ArrayToHexDump(bin)).toMatchInlineSnapshot(`
      "0000  01 00 00 00 76 01 01 61 77 02 39 39 01 02 03 7D  ....v..aw.99...}
      0010  BB 01                                            \xBB.              "
    `);
    expect(stream.getLength()).toBe(18);
    const readStream = createBinaryStreamDecoder(bin);
    expect(readStream.getOffset()).toBe(0);
    expect(readStream.readUint32()).toBe(1);
    expect(readStream.getOffset()).toBe(4);
    expect(readStream.read()).toEqual({ a: "99" });
    expect(readStream.readBytes(3)).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
    expect(readStream.read()).toBe(123);
    expect(readStream.getOffset()).toBe(bin.length);
  });
  it("should bitfield", () => {
    const bf = bitfield(1);
    bf.setBit(4);
    expect(bf.getValue()).toBe(17);
    bf.setBit(0, false);
    expect(bf.getValue()).toBe(16);
    bf.setBit(1);
    bf.setBit(5);
    bf.setBit(16);
    expect(bf.getValue().toString(2)).toMatchInlineSnapshot(
      '"10000000000110010"'
    );
    expect(bf.getValue()).toBe(65586);
    expect(bf.getBit(0)).toBe(false);
    expect(bf.getBit(4)).toBe(true);
    bf.toggleBit(4);
    expect(bf.getBit(4)).toBe(false);
    expect(bf.getValue()).toBe(65570);
  });
  it("should var bin", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeIntVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(128)).toMatchInlineSnapshot('"8002"');
    expect(enc(-1)).toMatchInlineSnapshot('"41"');
    expect(enc(-691529286)).toMatchInlineSnapshot('"c699bf9305"');
    expect(enc(691529286)).toMatchInlineSnapshot('"8699bf9305"');
  });
  it("should var bin uint", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeUintVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(127)).toMatchInlineSnapshot('"7f"');
    expect(enc(128)).toMatchInlineSnapshot(`"8001"`);
    expect(enc(255)).toMatchInlineSnapshot('"ff01"');
    expect(enc(256)).toMatchInlineSnapshot('"8002"');
    expect(enc(691529286)).toMatchInlineSnapshot('"c6ccdfc902"');
  });
});
//# sourceMappingURL=index.spec.js.map