import {
  Emitter
} from "../../chunk-ZVMU3WSX.js";
import {
  useDispose
} from "../../chunk-EK32D4RU.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-EC265RJR.js";
import "../../chunk-Q4U2LWXG.js";
import "../../chunk-W7LFRQ22.js";
import "../../chunk-F43DOT7T.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-XZKJFOLV.js";
import "../../chunk-MAHFB3CS.js";
import "../../chunk-EJVKADTL.js";
import "../../chunk-ERNLUGKM.js";
import "../../chunk-IXQQW2HU.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-VQP2U5NJ.js";
import "../../chunk-2NUBGBAZ.js";
import {
  objectInclusivePick,
  objectMap,
  objectMergeDisposable,
  objectOmit,
  objectPick
} from "../../chunk-JOGTJBRE.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-FPGKBYJC.js";
import "../../chunk-SIEZSWEQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-SW2CNWDU.js";
import "../../chunk-HWIBO3OW.js";
import "../../chunk-Z4LF2VTM.js";
import "../../chunk-CBA7RGFL.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-2OESVESN.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-V2ICHMP3.js";
import "../../chunk-CFAKTF25.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-VK2OFAYR.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-EWHIXGDN.js";
import "../../chunk-UHUPIXEQ.js";

// src/common/data/object.spec.ts
describe("object.spec", () => {
  it("should map it", async () => {
    const sample = {
      a: 1,
      b: 2
    };
    expect(objectMap(sample, (k, v) => v + 10)).toMatchInlineSnapshot(`
      Object {
        "a": 11,
        "b": 12,
      }
    `);
    expect(objectMap(sample, (k, v) => [`${k}_${v}`, k])).toMatchInlineSnapshot(`
        Object {
          "a_1": "a",
          "b_2": "b",
        }
      `);
  });
  it("should merge", async () => {
    const emitter = new Emitter();
    const obj = {
      dispose: useDispose(),
      f() {
        return 42;
      }
    };
    let x = 1;
    obj.dispose.add(() => x++);
    const m = objectMergeDisposable(emitter, obj);
    expect(m.f()).toBe(42);
    m.on("a", () => x++);
    m.emit("a");
    expect(x).toBe(2);
    await m.dispose();
    expect(x).toBe(3);
  });
  it("should omit and pick", () => {
    const o = { a: 1, b: 2, c: 3, d: 4 };
    expect(objectPick(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
      }
    `);
    expect(objectOmit(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "b": 2,
        "d": 4,
      }
    `);
    expect(objectInclusivePick(o, "a", "c", "x")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
        "x": undefined,
      }
    `);
  });
});
//# sourceMappingURL=object.spec.js.map