"use strict";

var _chunkJGSTQKRUcjs = require('../../chunk-JGSTQKRU.cjs');
require('../../chunk-M5A6E3IV.cjs');
require('../../chunk-XXOAD5DS.cjs');
require('../../chunk-XG57S66T.cjs');
require('../../chunk-ILU6JYIQ.cjs');
require('../../chunk-2ICTYHLD.cjs');
require('../../chunk-ROMJB24B.cjs');
require('../../chunk-FLEYODRW.cjs');
require('../../chunk-ZYPCVNSG.cjs');
require('../../chunk-VECBUBQP.cjs');
require('../../chunk-N46W55MH.cjs');
require('../../chunk-4DTP63TD.cjs');
require('../../chunk-ALCNRFOT.cjs');
require('../../chunk-44QLSR3L.cjs');
require('../../chunk-RHU3NAJJ.cjs');
require('../../chunk-5YJQXJJ2.cjs');
require('../../chunk-DRTH56G4.cjs');
require('../../chunk-KTC5RW57.cjs');
require('../../chunk-A4VFMLAN.cjs');
require('../../chunk-7XAMJGPO.cjs');
require('../../chunk-4775F523.cjs');
require('../../chunk-HUNMBCJM.cjs');
require('../../chunk-BJSAB3V6.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-5YFZ5XHS.cjs');
require('../../chunk-ZMMLSWTE.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-DLURJFPJ.cjs');
require('../../chunk-TLW7XWMG.cjs');
require('../../chunk-RUCUMN54.cjs');


var _chunkN5QVPPY5cjs = require('../../chunk-N5QVPPY5.cjs');
require('../../chunk-ANZPWIO4.cjs');
require('../../chunk-HGZBTWNM.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-P6CCMGL5.cjs');
require('../../chunk-2H3C4K3S.cjs');
require('../../chunk-FYLSPYV2.cjs');
require('../../chunk-YKRFYR2Q.cjs');
require('../../chunk-ZZSC3TSL.cjs');
require('../../chunk-BMRI2X66.cjs');
require('../../chunk-DG7AY3TM.cjs');
require('../../chunk-JGD7O5EZ.cjs');

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new (0, _chunkJGSTQKRUcjs.SerialQueue)();
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    (async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 100);
      list.push("a");
    })();
    (async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 200);
      list.push("b");
    })();
    (async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 1);
      list.push("c");
    })();
    await _chunkN5QVPPY5cjs.sleep.call(void 0, 500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new (0, _chunkJGSTQKRUcjs.SerialQueue)();
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkJGSTQKRUcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkJGSTQKRUcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await _chunkN5QVPPY5cjs.sleep.call(void 0, 1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.cjs.map