import {
  SerialQueue
} from "../../chunk-OYNSVQOM.js";
import "../../chunk-ZVMU3WSX.js";
import "../../chunk-4EOY6YSF.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-EC265RJR.js";
import "../../chunk-Q4U2LWXG.js";
import "../../chunk-W7LFRQ22.js";
import "../../chunk-F43DOT7T.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-5RFQXBFU.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-XZKJFOLV.js";
import "../../chunk-MAHFB3CS.js";
import "../../chunk-EJVKADTL.js";
import "../../chunk-ERNLUGKM.js";
import "../../chunk-IXQQW2HU.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-VQP2U5NJ.js";
import "../../chunk-2NUBGBAZ.js";
import "../../chunk-JOGTJBRE.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-FPGKBYJC.js";
import "../../chunk-SIEZSWEQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-SW2CNWDU.js";
import "../../chunk-HWIBO3OW.js";
import "../../chunk-Z4LF2VTM.js";
import {
  sleep
} from "../../chunk-CBA7RGFL.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-2OESVESN.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-V2ICHMP3.js";
import "../../chunk-CFAKTF25.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-VK2OFAYR.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-EWHIXGDN.js";
import "../../chunk-UHUPIXEQ.js";

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new SerialQueue();
    queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    (async () => {
      await sleep(100);
      list.push("a");
    })();
    (async () => {
      await sleep(200);
      list.push("b");
    })();
    (async () => {
      await sleep(1);
      list.push("c");
    })();
    await sleep(500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new SerialQueue();
    queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new SerialQueue();
    const events = [];
    queue.onAny((...args) => events.push(args));
    queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new SerialQueue();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.js.map