"use strict";

var _chunkROMJB24Bcjs = require('../../chunk-ROMJB24B.cjs');
require('../../chunk-FLEYODRW.cjs');
require('../../chunk-4DTP63TD.cjs');
require('../../chunk-ALCNRFOT.cjs');
require('../../chunk-RHU3NAJJ.cjs');
require('../../chunk-5YJQXJJ2.cjs');
require('../../chunk-DRTH56G4.cjs');
require('../../chunk-KTC5RW57.cjs');
require('../../chunk-A4VFMLAN.cjs');
require('../../chunk-7XAMJGPO.cjs');
require('../../chunk-4775F523.cjs');
require('../../chunk-HUNMBCJM.cjs');
require('../../chunk-BJSAB3V6.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-5YFZ5XHS.cjs');
require('../../chunk-ZMMLSWTE.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-DLURJFPJ.cjs');
require('../../chunk-TLW7XWMG.cjs');
require('../../chunk-RUCUMN54.cjs');
require('../../chunk-N5QVPPY5.cjs');
require('../../chunk-ANZPWIO4.cjs');
require('../../chunk-HGZBTWNM.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-P6CCMGL5.cjs');
require('../../chunk-2H3C4K3S.cjs');
require('../../chunk-FYLSPYV2.cjs');
require('../../chunk-YKRFYR2Q.cjs');
require('../../chunk-ZZSC3TSL.cjs');
require('../../chunk-BMRI2X66.cjs');
require('../../chunk-DG7AY3TM.cjs');
require('../../chunk-JGD7O5EZ.cjs');

// src/common/log/log.spec.ts
describe("logger", () => {
  it("should log different levels", () => {
    const messages = [];
    const logger = _chunkROMJB24Bcjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    log("Simple");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["Simple"],
        name: "test"
      },
      {
        level: 0,
        messages: ["Hello"],
        name: "test"
      },
      {
        level: 1,
        messages: ["World"],
        name: "test"
      },
      {
        level: 2,
        messages: ["is on"],
        name: "test"
      },
      {
        level: 3,
        messages: ["Fire"],
        name: "test"
      },
      {
        level: 4,
        messages: ["Fatal"],
        name: "test"
      }
    ]);
  });
  it("should log filter level", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkROMJB24Bcjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    expect(log.label).toBe("test");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      { name: "test", messages: ["Hello"], level: 0 },
      // xxx
      { name: "test", messages: ["World"], level: 1 },
      { name: "test", messages: ["is on"], level: 2 },
      { name: "test", messages: ["Fire"], level: 3 },
      { name: "test", messages: ["Fatal"], level: 4 }
    ]);
    {
      const log2 = log.extend("ext");
      log2.debug("Hello");
      log2.info("World2");
      log2.warn("is on");
      log2.error("Fire");
      try {
        log2.assert(false, "Fatal");
      } catch (err) {
      }
      expect(messages).toEqual([
        { name: "test", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test", messages: ["World"], level: 1 },
        { name: "test", messages: ["is on"], level: 2 },
        { name: "test", messages: ["Fire"], level: 3 },
        { name: "test", messages: ["Fatal"], level: 4 },
        { name: "test:ext", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test:ext", messages: ["World2"], level: 1 },
        { name: "test:ext", messages: ["is on"], level: 2 },
        { name: "test:ext", messages: ["Fire"], level: 3 },
        { name: "test:ext", messages: ["Fatal"], level: 4 }
      ]);
    }
  });
  it("should log filter namespace", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkROMJB24Bcjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    logger.setFilter("a*,-ab");
    const aa = logger("aa");
    const ab = logger("ab");
    const xy = logger("xy");
    aa("aa");
    ab("ab");
    xy("xy");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      }
    ]);
    const xyz = aa.extend("xyz");
    xyz("xyz");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      },
      {
        level: 0,
        messages: ["xyz"],
        name: "aa:xyz"
      }
    ]);
  });
  it("should fake log", () => {
    const messages = [];
    const logger = _chunkROMJB24Bcjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test", false);
    const { info, error, warn, debug, assert } = log;
    log("Simple");
    debug("Hello");
    info("World");
    warn("is on");
    error("Fire");
    expect(messages).toEqual([]);
  });
});
//# sourceMappingURL=log.spec.cjs.map