import { LoggerInterface } from '../log/log-base.cjs';

type ArgumentsType<T> = T extends (...args: infer A) => any ? A : never;
type ReturnType<T> = T extends (...args: any) => infer R ? R : never;
interface RPCOptionsBasic {
    /** No return values expected */
    onlyEvents?: boolean;
    /** Function to post raw message */
    post: (data: any) => void;
    /** Listener to receive raw message */
    on: (fn: (data: any) => void) => void;
    /** Custom function to serialize data */
    serialize?: (data: any) => any;
    /** Custom function to deserialize data */
    deserialize?: (data: any) => any;
    /** Custom logger */
    log?: LoggerInterface;
}
interface RPCOptions<Remote> extends RPCOptionsBasic {
    /** Names of remote functions that do not need response. */
    eventNames?: (keyof Remote)[];
}
interface RPCFn<T> {
    /** Call the remote function and wait for the result. */
    (...args: ArgumentsType<T>): Promise<Awaited<ReturnType<T>>>;
    /** Send event without asking for response */
    asEvent(...args: ArgumentsType<T>): void;
}
type RPCReturn<RemoteFunctions> = {
    [K in keyof RemoteFunctions]: RPCFn<RemoteFunctions[K]>;
};
declare function useRPC<LocalFunctions, RemoteFunctions = LocalFunctions>(functions: LocalFunctions, options: RPCOptions<RemoteFunctions>): RPCReturn<RemoteFunctions>;
declare function useRPCHub(options: RPCOptionsBasic): <LocalFunctions, RemoteFunctions = LocalFunctions>(additionalFunctions?: LocalFunctions | undefined, additionalEventNames?: string[]) => RPCReturn<RemoteFunctions>;
type UseRPCHubType = ReturnType<typeof useRPCHub>;

export { type ArgumentsType, type RPCFn, type RPCOptions, type RPCOptionsBasic, type RPCReturn, type ReturnType, type UseRPCHubType, useRPC, useRPCHub };
