import {
  decodeJson,
  encodeJson
} from "../../chunk-KZGDS2U4.js";
import "../../chunk-757WXGDS.js";
import "../../chunk-MKG75UEC.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-IRAXCYXQ.js";
import {
  useRPC,
  useRPCHub
} from "../../chunk-BZI4YHUE.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-EC265RJR.js";
import "../../chunk-Q4U2LWXG.js";
import "../../chunk-W7LFRQ22.js";
import "../../chunk-F43DOT7T.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-XZKJFOLV.js";
import "../../chunk-MAHFB3CS.js";
import "../../chunk-EJVKADTL.js";
import "../../chunk-ERNLUGKM.js";
import "../../chunk-IXQQW2HU.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-VQP2U5NJ.js";
import "../../chunk-2NUBGBAZ.js";
import "../../chunk-JOGTJBRE.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-FPGKBYJC.js";
import "../../chunk-SIEZSWEQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-SW2CNWDU.js";
import "../../chunk-HWIBO3OW.js";
import "../../chunk-Z4LF2VTM.js";
import "../../chunk-CBA7RGFL.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-2OESVESN.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-V2ICHMP3.js";
import "../../chunk-CFAKTF25.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-VK2OFAYR.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-EWHIXGDN.js";
import "../../chunk-UHUPIXEQ.js";

// src/common/msg/rpc.spec.ts
import { MessageChannel } from "node:worker_threads";
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("hub", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
});
//# sourceMappingURL=rpc.spec.js.map